diff --git a/src/Numerics/LinearAlgebra/Complex/SparseVector.cs b/src/Numerics/LinearAlgebra/Complex/SparseVector.cs
index 5d2673a0..aa18a3a1 100644
--- a/src/Numerics/LinearAlgebra/Complex/SparseVector.cs
+++ b/src/Numerics/LinearAlgebra/Complex/SparseVector.cs
@@ -1206,14 +1206,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex
}
///
- /// Tensor Product (Outer) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(SparseVector v)
+ public Matrix OuterProduct(SparseVector v)
{
return OuterProduct(this, v);
}
diff --git a/src/Numerics/LinearAlgebra/Complex32/SparseVector.cs b/src/Numerics/LinearAlgebra/Complex32/SparseVector.cs
index ead46d83..59253675 100644
--- a/src/Numerics/LinearAlgebra/Complex32/SparseVector.cs
+++ b/src/Numerics/LinearAlgebra/Complex32/SparseVector.cs
@@ -1206,14 +1206,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex32
}
///
- /// Tensor Product (Outer) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(SparseVector v)
+ public Matrix OuterProduct(SparseVector v)
{
return OuterProduct(this, v);
}
diff --git a/src/Numerics/LinearAlgebra/Double/SparseVector.cs b/src/Numerics/LinearAlgebra/Double/SparseVector.cs
index 6ef0ad24..c006e501 100644
--- a/src/Numerics/LinearAlgebra/Double/SparseVector.cs
+++ b/src/Numerics/LinearAlgebra/Double/SparseVector.cs
@@ -1205,14 +1205,14 @@ namespace MathNet.Numerics.LinearAlgebra.Double
}
///
- /// Tensor Product (Outer) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(SparseVector v)
+ public Matrix OuterProduct(SparseVector v)
{
return OuterProduct(this, v);
}
diff --git a/src/Numerics/LinearAlgebra/Single/SparseVector.cs b/src/Numerics/LinearAlgebra/Single/SparseVector.cs
index 9193bd89..46937e42 100644
--- a/src/Numerics/LinearAlgebra/Single/SparseVector.cs
+++ b/src/Numerics/LinearAlgebra/Single/SparseVector.cs
@@ -1205,14 +1205,14 @@ namespace MathNet.Numerics.LinearAlgebra.Single
}
///
- /// Tensor Product (Outer) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(SparseVector v)
+ public Matrix OuterProduct(SparseVector v)
{
return OuterProduct(this, v);
}
diff --git a/src/UnitTests/LinearAlgebraTests/Complex/VectorTests.Arithmetic.cs b/src/UnitTests/LinearAlgebraTests/Complex/VectorTests.Arithmetic.cs
index b3643e79..447a4afc 100644
--- a/src/UnitTests/LinearAlgebraTests/Complex/VectorTests.Arithmetic.cs
+++ b/src/UnitTests/LinearAlgebraTests/Complex/VectorTests.Arithmetic.cs
@@ -880,7 +880,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Complex
{
var vector1 = CreateVector(Data);
var vector2 = CreateVector(Data);
- var m = vector1.TensorMultiply(vector2);
+ var m = vector1.OuterProduct(vector2);
for (var i = 0; i < vector1.Count; i++)
{
for (var j = 0; j < vector2.Count; j++)
@@ -896,7 +896,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Complex
{
var vector1 = CreateVector(Data);
Vector vector2 = null;
- vector1.TensorMultiply(vector2);
+ vector1.OuterProduct(vector2);
}
}
}
\ No newline at end of file
diff --git a/src/UnitTests/LinearAlgebraTests/Complex32/VectorTests.Arithmetic.cs b/src/UnitTests/LinearAlgebraTests/Complex32/VectorTests.Arithmetic.cs
index 7e1a9a70..1c75fc24 100644
--- a/src/UnitTests/LinearAlgebraTests/Complex32/VectorTests.Arithmetic.cs
+++ b/src/UnitTests/LinearAlgebraTests/Complex32/VectorTests.Arithmetic.cs
@@ -880,7 +880,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Complex32
{
var vector1 = CreateVector(Data);
var vector2 = CreateVector(Data);
- var m = vector1.TensorMultiply(vector2);
+ var m = vector1.OuterProduct(vector2);
for (var i = 0; i < vector1.Count; i++)
{
for (var j = 0; j < vector2.Count; j++)
@@ -896,7 +896,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Complex32
{
var vector1 = CreateVector(Data);
Vector vector2 = null;
- vector1.TensorMultiply(vector2);
+ vector1.OuterProduct(vector2);
}
}
}
\ No newline at end of file
diff --git a/src/UnitTests/LinearAlgebraTests/Double/VectorTests.Arithmetic.cs b/src/UnitTests/LinearAlgebraTests/Double/VectorTests.Arithmetic.cs
index dcce3cf7..217b05c0 100644
--- a/src/UnitTests/LinearAlgebraTests/Double/VectorTests.Arithmetic.cs
+++ b/src/UnitTests/LinearAlgebraTests/Double/VectorTests.Arithmetic.cs
@@ -880,7 +880,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Double
{
var vector1 = CreateVector(Data);
var vector2 = CreateVector(Data);
- var m = vector1.TensorMultiply(vector2);
+ var m = vector1.OuterProduct(vector2);
for (var i = 0; i < vector1.Count; i++)
{
for (var j = 0; j < vector2.Count; j++)
@@ -896,7 +896,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Double
{
var vector1 = CreateVector(Data);
Vector vector2 = null;
- vector1.TensorMultiply(vector2);
+ vector1.OuterProduct(vector2);
}
}
}
\ No newline at end of file
diff --git a/src/UnitTests/LinearAlgebraTests/Single/VectorTests.Arithmetic.cs b/src/UnitTests/LinearAlgebraTests/Single/VectorTests.Arithmetic.cs
index 4030841c..53f1ca61 100644
--- a/src/UnitTests/LinearAlgebraTests/Single/VectorTests.Arithmetic.cs
+++ b/src/UnitTests/LinearAlgebraTests/Single/VectorTests.Arithmetic.cs
@@ -879,7 +879,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Single
{
var vector1 = CreateVector(Data);
var vector2 = CreateVector(Data);
- var m = vector1.TensorMultiply(vector2);
+ var m = vector1.OuterProduct(vector2);
for (var i = 0; i < vector1.Count; i++)
{
for (var j = 0; j < vector2.Count; j++)
@@ -895,7 +895,7 @@ namespace MathNet.Numerics.UnitTests.LinearAlgebraTests.Single
{
var vector1 = CreateVector(Data);
Vector vector2 = null;
- vector1.TensorMultiply(vector2);
+ vector1.OuterProduct(vector2);
}
}
}
\ No newline at end of file
diff --git a/src/Numerics/LinearAlgebra/Complex/DenseVector.cs b/src/Numerics/LinearAlgebra/Complex/DenseVector.cs
index c6537664..983c7cb2 100644
--- a/src/Numerics/LinearAlgebra/Complex/DenseVector.cs
+++ b/src/Numerics/LinearAlgebra/Complex/DenseVector.cs
@@ -1154,14 +1154,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex
}
///
/// Tensor Product (Dyadic) of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(DenseVector v)
+ public Matrix OuterProduct(DenseVector v)
{
return OuterProduct(this, v);
}
@@ -1154,14 +1154,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex
}
///
- /// Tensor Product (Dyadic) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
diff --git a/src/Numerics/LinearAlgebra/Complex32/DenseVector.cs b/src/Numerics/LinearAlgebra/Complex32/DenseVector.cs
index f6ffb256..6c778ba4 100644
--- a/src/Numerics/LinearAlgebra/Complex32/DenseVector.cs
+++ b/src/Numerics/LinearAlgebra/Complex32/DenseVector.cs
@@ -1154,14 +1154,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex32
}
///
/// Tensor Product (Dyadic) of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(DenseVector v)
+ public Matrix OuterProduct(DenseVector v)
{
return OuterProduct(this, v);
}
@@ -1154,14 +1154,14 @@ namespace MathNet.Numerics.LinearAlgebra.Complex32
}
///
- /// Tensor Product (Dyadic) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
diff --git a/src/Numerics/LinearAlgebra/Double/DenseVector.cs b/src/Numerics/LinearAlgebra/Double/DenseVector.cs
index 89fe5674..98f49638 100644
--- a/src/Numerics/LinearAlgebra/Double/DenseVector.cs
+++ b/src/Numerics/LinearAlgebra/Double/DenseVector.cs
@@ -1246,14 +1246,14 @@ namespace MathNet.Numerics.LinearAlgebra.Double
}
///
/// Tensor Product (Dyadic) of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(DenseVector v)
+ public Matrix OuterProduct(DenseVector v)
{
return OuterProduct(this, v);
}
@@ -1246,14 +1246,14 @@ namespace MathNet.Numerics.LinearAlgebra.Double
}
///
- /// Tensor Product (Dyadic) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
diff --git a/src/Numerics/LinearAlgebra/Generic/Vector.cs b/src/Numerics/LinearAlgebra/Generic/Vector.cs
index 71991fb4..c664b7b8 100644
--- a/src/Numerics/LinearAlgebra/Generic/Vector.cs
+++ b/src/Numerics/LinearAlgebra/Generic/Vector.cs
@@ -753,14 +753,14 @@ namespace MathNet.Numerics.LinearAlgebra.Generic
public abstract Vector Random(int length, IDiscreteDistribution randomDistribution);
///
/// Tensor Product (Dyadic) of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(Vector v)
+ public Matrix OuterProduct(Vector v)
{
return OuterProduct(this, v);
}
@@ -753,14 +753,14 @@ namespace MathNet.Numerics.LinearAlgebra.Generic
public abstract Vector Random(int length, IDiscreteDistribution randomDistribution);
///
- /// Tensor Product (Dyadic) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.
diff --git a/src/Numerics/LinearAlgebra/Single/DenseVector.cs b/src/Numerics/LinearAlgebra/Single/DenseVector.cs
index f1459ece..c43bf0b8 100644
--- a/src/Numerics/LinearAlgebra/Single/DenseVector.cs
+++ b/src/Numerics/LinearAlgebra/Single/DenseVector.cs
@@ -1246,14 +1246,14 @@ namespace MathNet.Numerics.LinearAlgebra.Single
}
///
/// Tensor Product (Dyadic) of this and another vector.
///
/// The vector to operate on.
///
/// Matrix M[i,j] = this[i] * v[j].
///
///
- public Matrix TensorMultiply(DenseVector v)
+ public Matrix OuterProduct(DenseVector v)
{
return OuterProduct(this, v);
}
@@ -1246,14 +1246,14 @@ namespace MathNet.Numerics.LinearAlgebra.Single
}
///
- /// Tensor Product (Dyadic) of this and another vector.
+ /// Outer product of this and another vector.
///
/// The vector to operate on.